@@ -8,12 +8,10 @@ use parent qw(Math::Bacovia);
 
 our $VERSION = $Math::Bacovia::VERSION;
 
-my %cache;
-
 sub new {
     my ($class, $value) = @_;
     Math::Bacovia::_check_type(\$value);
-    $cache{$value->stringify} //= bless {value => $value}, $class;
+    bless {value => $value}, $class;
 }
 
 sub get {
